@@ -86,6 +86,10 @@ seconds.
 
 Be verbose about communicating with KGB server.
 
+=item B<dry_run>
+
+Perform all processing, but do not communicate with the server.
+
 =back
 
 =head1 METHODS
@@ -143,7 +147,7 @@ Helper method sending commit information via JSON-RPC. Dies on errors.
 require v5.10.0;
 use base 'Class::Accessor::Fast';
 
-__PACKAGE__->mk_accessors( qw( uri proxy password timeout verbose ) );
+__PACKAGE__->mk_accessors( qw( uri proxy password timeout verbose dry_run ) );
 
 use utf8;
 use Carp qw(confess);
@@ -211,7 +215,7 @@ sub send_changes {
 
     my $meth;
     if ( $protocol_ver eq 'auto' ) {
-        $meth = 'send_changes_json';
+        $meth = 'send_changes_v4';
     }
     else {
         $meth = "send_changes_v$protocol_ver";
@@ -219,11 +223,6 @@ sub send_changes {
             unless $self->can($meth);
     }
 
-    if ( $self->verbose ) {
-        print "About to contact ", $self->proxy, "\n";
-        print "Commit: ", YAML::Dump($info), "\n";
-    }
-
     $self->$meth($info);
 }
 
@@ -239,6 +238,14 @@ sub send_changes_soap {
 
     require SOAP::Lite;
 
+    if ( $self->verbose ) {
+        printf "SOAP call: %s/%s\n", $self->uri, $self->proxy;
+        print "Message:\n", YAML::Dump($message);
+    }
+    if ( $self->dry_run ) {
+        return;
+    }
+
     my $s = SOAP::Lite->new( uri => $self->uri, proxy => $self->proxy );
     $s->transport->proxy->timeout( $self->timeout // 15 );
 
@@ -289,6 +296,15 @@ sub send_changes_json {
     $rpc->ua->default_header( 'X-KGB-Auth', $hash );
     $rpc->ua->default_header( 'X-KGB-Project', $repo_id );
 
+    if ( $self->verbose ) {
+        printf "JSON/RPC call: %s/json-rpc\n", $self->uri;
+        print "Headers:\n", $rpc->ua->default_headers->as_string;
+        print "Message:\n", YAML::Dump($message);
+    }
+    if ( $self->dry_run ) {
+        return;
+    }
+
     my $res = $rpc->call( $self->uri . '/json-rpc', $message );
 
     die "Transport error: " . $rpc->status_line . "\n" unless $res;
